@@ -23,6 +23,7 @@
 #ifdef HAVE_LIBINTL
 
 #include <stdio.h>
+#include <locale.h>
 #include "ext/standard/info.h"
 #include "php_gettext.h"
 #include "gettext_arginfo.h"
@@ -146,6 +147,9 @@ PHP_FUNCTION(dcgettext)
 
 	PHP_GETTEXT_DOMAIN_LENGTH_CHECK(1, ZSTR_LEN(domain))
 	PHP_GETTEXT_LENGTH_CHECK(2, ZSTR_LEN(msgid))
+	if (category == LC_ALL) {
+		RETURN_STR_COPY(msgid);
+	}
 
 	msgstr = dcgettext(ZSTR_VAL(domain), ZSTR_VAL(msgid), category);
 
@@ -260,6 +264,9 @@ PHP_FUNCTION(dcngettext)
 	PHP_GETTEXT_DOMAIN_LENGTH_CHECK(1, domain_len)
 	PHP_GETTEXT_LENGTH_CHECK(2, msgid1_len)
 	PHP_GETTEXT_LENGTH_CHECK(3, msgid2_len)
+	if (category == LC_ALL) {
+		RETURN_STRING(msgid1);
+	}
 
 	msgstr = dcngettext(domain, msgid1, msgid2, count, category);
 
