@@ -1,5 +1,5 @@
 /* This is a generated file, edit the .stub.php file instead.
- * Stub hash: a8562e63010e127aadb97134733ac328ced3c7bf */
+ * Stub hash: 00f5d4fc74e8b7dc67da6f12180c9fae343954cc */
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar___construct, 0, 0, 1)
 	ZEND_ARG_TYPE_INFO(0, filename, IS_STRING, 0)
@@ -10,59 +10,63 @@ ZEND_END_ARG_INFO()
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar___destruct, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_addEmptyDir, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_addEmptyDir, 0, 1, IS_VOID, 0)
 	ZEND_ARG_TYPE_INFO(0, directory, IS_STRING, 0)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_addFile, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_addFile, 0, 1, IS_VOID, 0)
 	ZEND_ARG_TYPE_INFO(0, filename, IS_STRING, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, localName, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_addFromString, 0, 0, 2)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_addFromString, 0, 2, IS_VOID, 0)
 	ZEND_ARG_TYPE_INFO(0, localName, IS_STRING, 0)
 	ZEND_ARG_TYPE_INFO(0, contents, IS_STRING, 0)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_buildFromDirectory, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_buildFromDirectory, 0, 1, IS_ARRAY, 0)
 	ZEND_ARG_TYPE_INFO(0, directory, IS_STRING, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, pattern, IS_STRING, 0, "\"\"")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_buildFromIterator, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_buildFromIterator, 0, 1, IS_ARRAY, 0)
 	ZEND_ARG_OBJ_INFO(0, iterator, Traversable, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, baseDirectory, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_compressFiles, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_compressFiles, 0, 1, IS_VOID, 0)
 	ZEND_ARG_TYPE_INFO(0, compression, IS_LONG, 0)
 ZEND_END_ARG_INFO()
 
 #define arginfo_class_Phar_decompressFiles arginfo_class_Phar___destruct
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_compress, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_OBJ_INFO_EX(arginfo_class_Phar_compress, 0, 1, Phar, 1)
 	ZEND_ARG_TYPE_INFO(0, compression, IS_LONG, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, extension, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_decompress, 0, 0, 0)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_OBJ_INFO_EX(arginfo_class_Phar_decompress, 0, 0, Phar, 1)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, extension, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_convertToExecutable, 0, 0, 0)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_OBJ_INFO_EX(arginfo_class_Phar_convertToExecutable, 0, 0, Phar, 1)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, format, IS_LONG, 1, "null")
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, compression, IS_LONG, 1, "null")
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, extension, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_convertToData arginfo_class_Phar_convertToExecutable
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_copy, 0, 0, 2)
-	ZEND_ARG_TYPE_INFO(0, to, IS_STRING, 0)
-	ZEND_ARG_TYPE_INFO(0, from, IS_STRING, 0)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_OBJ_INFO_EX(arginfo_class_Phar_convertToData, 0, 0, PharData, 1)
+	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, format, IS_LONG, 1, "null")
+	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, compression, IS_LONG, 1, "null")
+	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, extension, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_count, 0, 0, 0)
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_copy, 0, 0, 2)
+	ZEND_ARG_TYPE_INFO(0, from, IS_STRING, 0)
+	ZEND_ARG_TYPE_INFO(0, to, IS_STRING, 0)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_count, 0, 0, IS_LONG, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, mode, IS_LONG, 0, "COUNT_NORMAL")
 ZEND_END_ARG_INFO()
 
@@ -72,67 +76,76 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_class_Phar_delMetadata arginfo_class_Phar___destruct
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_extractTo, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_extractTo, 0, 1, _IS_BOOL, 0)
 	ZEND_ARG_TYPE_INFO(0, directory, IS_STRING, 0)
 	ZEND_ARG_TYPE_MASK(0, files, MAY_BE_ARRAY|MAY_BE_STRING|MAY_BE_NULL, "null")
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, overwrite, _IS_BOOL, 0, "false")
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_getAlias arginfo_class_Phar___destruct
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_getAlias, 0, 0, IS_STRING, 1)
+ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_getPath arginfo_class_Phar___destruct
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_getPath, 0, 0, IS_STRING, 0)
+ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_getMetadata, 0, 0, 0)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_getMetadata, 0, 0, IS_MIXED, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, unserializeOptions, IS_ARRAY, 0, "[]")
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_getModified arginfo_class_Phar___destruct
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_getModified, 0, 0, _IS_BOOL, 0)
+ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_getSignature arginfo_class_Phar___destruct
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_MASK_EX(arginfo_class_Phar_getSignature, 0, 0, MAY_BE_ARRAY|MAY_BE_FALSE)
+ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_getStub arginfo_class_Phar___destruct
+#define arginfo_class_Phar_getStub arginfo_class_Phar_getPath
 
-#define arginfo_class_Phar_getVersion arginfo_class_Phar___destruct
+#define arginfo_class_Phar_getVersion arginfo_class_Phar_getPath
 
-#define arginfo_class_Phar_hasMetadata arginfo_class_Phar___destruct
+#define arginfo_class_Phar_hasMetadata arginfo_class_Phar_getModified
 
-#define arginfo_class_Phar_isBuffering arginfo_class_Phar___destruct
+#define arginfo_class_Phar_isBuffering arginfo_class_Phar_getModified
 
-#define arginfo_class_Phar_isCompressed arginfo_class_Phar___destruct
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_MASK_EX(arginfo_class_Phar_isCompressed, 0, 0, MAY_BE_LONG|MAY_BE_FALSE)
+ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_isFileFormat, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_isFileFormat, 0, 1, _IS_BOOL, 0)
 	ZEND_ARG_TYPE_INFO(0, format, IS_LONG, 0)
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_isWritable arginfo_class_Phar___destruct
+#define arginfo_class_Phar_isWritable arginfo_class_Phar_getModified
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_offsetExists, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_offsetExists, 0, 1, _IS_BOOL, 0)
 	ZEND_ARG_INFO(0, localName)
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_offsetGet arginfo_class_Phar_offsetExists
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_OBJ_INFO_EX(arginfo_class_Phar_offsetGet, 0, 1, SplFileInfo, 0)
+	ZEND_ARG_INFO(0, localName)
+ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_offsetSet, 0, 0, 2)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_offsetSet, 0, 2, IS_VOID, 0)
 	ZEND_ARG_INFO(0, localName)
 	ZEND_ARG_INFO(0, value)
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_offsetUnset arginfo_class_Phar_offsetExists
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_offsetUnset, 0, 1, IS_VOID, 0)
+	ZEND_ARG_INFO(0, localName)
+ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_setAlias, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_setAlias, 0, 1, _IS_BOOL, 0)
 	ZEND_ARG_TYPE_INFO(0, alias, IS_STRING, 0)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_setDefaultStub, 0, 0, 0)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_setDefaultStub, 0, 0, _IS_BOOL, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, index, IS_STRING, 1, "null")
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, webIndex, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_setMetadata, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_setMetadata, 0, 1, IS_VOID, 0)
 	ZEND_ARG_TYPE_INFO(0, metadata, IS_MIXED, 0)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_setSignatureAlgorithm, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_setSignatureAlgorithm, 0, 1, IS_VOID, 0)
 	ZEND_ARG_TYPE_INFO(0, algo, IS_LONG, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, privateKey, IS_STRING, 1, "null")
 ZEND_END_ARG_INFO()
@@ -142,9 +155,10 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_class_Phar_setStub, 0, 0, 1)
 	ZEND_ARG_TYPE_INFO(0, length, IS_LONG, 0)
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_startBuffering arginfo_class_Phar___destruct
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_Phar_startBuffering, 0, 0, IS_VOID, 0)
+ZEND_END_ARG_INFO()
 
-#define arginfo_class_Phar_stopBuffering arginfo_class_Phar___destruct
+#define arginfo_class_Phar_stopBuffering arginfo_class_Phar_startBuffering
 
 ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_class_Phar_apiVersion, 0, 0, IS_STRING, 0)
 ZEND_END_ARG_INFO()
@@ -232,13 +246,18 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_class_PharData_decompressFiles arginfo_class_Phar___destruct
 
-#define arginfo_class_PharData_compress arginfo_class_Phar_compress
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_OBJ_INFO_EX(arginfo_class_PharData_compress, 0, 1, PharData, 1)
+	ZEND_ARG_TYPE_INFO(0, compression, IS_LONG, 0)
+	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, extension, IS_STRING, 1, "null")
+ZEND_END_ARG_INFO()
 
-#define arginfo_class_PharData_decompress arginfo_class_Phar_decompress
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_OBJ_INFO_EX(arginfo_class_PharData_decompress, 0, 0, PharData, 1)
+	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, extension, IS_STRING, 1, "null")
+ZEND_END_ARG_INFO()
 
 #define arginfo_class_PharData_convertToExecutable arginfo_class_Phar_convertToExecutable
 
-#define arginfo_class_PharData_convertToData arginfo_class_Phar_convertToExecutable
+#define arginfo_class_PharData_convertToData arginfo_class_Phar_convertToData
 
 #define arginfo_class_PharData_copy arginfo_class_Phar_copy
 
@@ -250,37 +269,37 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_class_PharData_extractTo arginfo_class_Phar_extractTo
 
-#define arginfo_class_PharData_getAlias arginfo_class_Phar___destruct
+#define arginfo_class_PharData_getAlias arginfo_class_Phar_getAlias
 
-#define arginfo_class_PharData_getPath arginfo_class_Phar___destruct
+#define arginfo_class_PharData_getPath arginfo_class_Phar_getPath
 
 #define arginfo_class_PharData_getMetadata arginfo_class_Phar_getMetadata
 
-#define arginfo_class_PharData_getModified arginfo_class_Phar___destruct
+#define arginfo_class_PharData_getModified arginfo_class_Phar_getModified
 
-#define arginfo_class_PharData_getSignature arginfo_class_Phar___destruct
+#define arginfo_class_PharData_getSignature arginfo_class_Phar_getSignature
 
-#define arginfo_class_PharData_getStub arginfo_class_Phar___destruct
+#define arginfo_class_PharData_getStub arginfo_class_Phar_getPath
 
-#define arginfo_class_PharData_getVersion arginfo_class_Phar___destruct
+#define arginfo_class_PharData_getVersion arginfo_class_Phar_getPath
 
-#define arginfo_class_PharData_hasMetadata arginfo_class_Phar___destruct
+#define arginfo_class_PharData_hasMetadata arginfo_class_Phar_getModified
 
-#define arginfo_class_PharData_isBuffering arginfo_class_Phar___destruct
+#define arginfo_class_PharData_isBuffering arginfo_class_Phar_getModified
 
-#define arginfo_class_PharData_isCompressed arginfo_class_Phar___destruct
+#define arginfo_class_PharData_isCompressed arginfo_class_Phar_isCompressed
 
 #define arginfo_class_PharData_isFileFormat arginfo_class_Phar_isFileFormat
 
-#define arginfo_class_PharData_isWritable arginfo_class_Phar___destruct
+#define arginfo_class_PharData_isWritable arginfo_class_Phar_getModified
 
 #define arginfo_class_PharData_offsetExists arginfo_class_Phar_offsetExists
 
-#define arginfo_class_PharData_offsetGet arginfo_class_Phar_offsetExists
+#define arginfo_class_PharData_offsetGet arginfo_class_Phar_offsetGet
 
 #define arginfo_class_PharData_offsetSet arginfo_class_Phar_offsetSet
 
-#define arginfo_class_PharData_offsetUnset arginfo_class_Phar_offsetExists
+#define arginfo_class_PharData_offsetUnset arginfo_class_Phar_offsetUnset
 
 #define arginfo_class_PharData_setAlias arginfo_class_Phar_setAlias
 
@@ -292,9 +311,9 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_class_PharData_setStub arginfo_class_Phar_setStub
 
-#define arginfo_class_PharData_startBuffering arginfo_class_Phar___destruct
+#define arginfo_class_PharData_startBuffering arginfo_class_Phar_startBuffering
 
-#define arginfo_class_PharData_stopBuffering arginfo_class_Phar___destruct
+#define arginfo_class_PharData_stopBuffering arginfo_class_Phar_startBuffering
 
 #define arginfo_class_PharData_apiVersion arginfo_class_Phar_apiVersion
 
@@ -332,33 +351,36 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_class_PharFileInfo___destruct arginfo_class_Phar___destruct
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_PharFileInfo_chmod, 0, 0, 1)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_PharFileInfo_chmod, 0, 1, IS_VOID, 0)
 	ZEND_ARG_TYPE_INFO(0, perms, IS_LONG, 0)
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_PharFileInfo_compress arginfo_class_Phar_compressFiles
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_PharFileInfo_compress, 0, 0, 1)
+	ZEND_ARG_TYPE_INFO(0, compression, IS_LONG, 0)
+ZEND_END_ARG_INFO()
 
 #define arginfo_class_PharFileInfo_decompress arginfo_class_Phar___destruct
 
 #define arginfo_class_PharFileInfo_delMetadata arginfo_class_Phar___destruct
 
-#define arginfo_class_PharFileInfo_getCompressedSize arginfo_class_Phar___destruct
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_PharFileInfo_getCompressedSize, 0, 0, IS_LONG, 0)
+ZEND_END_ARG_INFO()
 
-#define arginfo_class_PharFileInfo_getCRC32 arginfo_class_Phar___destruct
+#define arginfo_class_PharFileInfo_getCRC32 arginfo_class_PharFileInfo_getCompressedSize
 
-#define arginfo_class_PharFileInfo_getContent arginfo_class_Phar___destruct
+#define arginfo_class_PharFileInfo_getContent arginfo_class_Phar_getPath
 
 #define arginfo_class_PharFileInfo_getMetadata arginfo_class_Phar_getMetadata
 
-#define arginfo_class_PharFileInfo_getPharFlags arginfo_class_Phar___destruct
+#define arginfo_class_PharFileInfo_getPharFlags arginfo_class_PharFileInfo_getCompressedSize
 
-#define arginfo_class_PharFileInfo_hasMetadata arginfo_class_Phar___destruct
+#define arginfo_class_PharFileInfo_hasMetadata arginfo_class_Phar_getModified
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_PharFileInfo_isCompressed, 0, 0, 0)
+ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_PharFileInfo_isCompressed, 0, 0, _IS_BOOL, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, compression, IS_LONG, 1, "null")
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_PharFileInfo_isCRCChecked arginfo_class_Phar___destruct
+#define arginfo_class_PharFileInfo_isCRCChecked arginfo_class_Phar_getModified
 
 #define arginfo_class_PharFileInfo_setMetadata arginfo_class_Phar_setMetadata
 
@@ -581,3 +603,141 @@ static const zend_function_entry class_PharFileInfo_methods[] = {
 	ZEND_ME(PharFileInfo, setMetadata, arginfo_class_PharFileInfo_setMetadata, ZEND_ACC_PUBLIC)
 	ZEND_FE_END
 };
+
+static zend_class_entry *register_class_PharException(zend_class_entry *class_entry_Exception)
+{
+	zend_class_entry ce, *class_entry;
+
+	INIT_CLASS_ENTRY(ce, "PharException", class_PharException_methods);
+	class_entry = zend_register_internal_class_ex(&ce, class_entry_Exception);
+
+	return class_entry;
+}
+
+static zend_class_entry *register_class_Phar(zend_class_entry *class_entry_RecursiveDirectoryIterator, zend_class_entry *class_entry_Countable, zend_class_entry *class_entry_ArrayAccess)
+{
+	zend_class_entry ce, *class_entry;
+
+	INIT_CLASS_ENTRY(ce, "Phar", class_Phar_methods);
+	class_entry = zend_register_internal_class_ex(&ce, class_entry_RecursiveDirectoryIterator);
+	zend_class_implements(class_entry, 2, class_entry_Countable, class_entry_ArrayAccess);
+
+	zval const_BZ2_value;
+	ZVAL_LONG(&const_BZ2_value, PHAR_ENT_COMPRESSED_BZ2);
+	zend_string *const_BZ2_name = zend_string_init_interned("BZ2", sizeof("BZ2") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_BZ2_name, &const_BZ2_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_BZ2_name);
+
+	zval const_GZ_value;
+	ZVAL_LONG(&const_GZ_value, PHAR_ENT_COMPRESSED_GZ);
+	zend_string *const_GZ_name = zend_string_init_interned("GZ", sizeof("GZ") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_GZ_name, &const_GZ_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_GZ_name);
+
+	zval const_NONE_value;
+	ZVAL_LONG(&const_NONE_value, PHAR_ENT_COMPRESSED_NONE);
+	zend_string *const_NONE_name = zend_string_init_interned("NONE", sizeof("NONE") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_NONE_name, &const_NONE_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_NONE_name);
+
+	zval const_PHAR_value;
+	ZVAL_LONG(&const_PHAR_value, PHAR_FORMAT_PHAR);
+	zend_string *const_PHAR_name = zend_string_init_interned("PHAR", sizeof("PHAR") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_PHAR_name, &const_PHAR_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_PHAR_name);
+
+	zval const_TAR_value;
+	ZVAL_LONG(&const_TAR_value, PHAR_FORMAT_TAR);
+	zend_string *const_TAR_name = zend_string_init_interned("TAR", sizeof("TAR") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_TAR_name, &const_TAR_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_TAR_name);
+
+	zval const_ZIP_value;
+	ZVAL_LONG(&const_ZIP_value, PHAR_FORMAT_ZIP);
+	zend_string *const_ZIP_name = zend_string_init_interned("ZIP", sizeof("ZIP") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_ZIP_name, &const_ZIP_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_ZIP_name);
+
+	zval const_COMPRESSED_value;
+	ZVAL_LONG(&const_COMPRESSED_value, PHAR_ENT_COMPRESSION_MASK);
+	zend_string *const_COMPRESSED_name = zend_string_init_interned("COMPRESSED", sizeof("COMPRESSED") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_COMPRESSED_name, &const_COMPRESSED_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_COMPRESSED_name);
+
+	zval const_PHP_value;
+	ZVAL_LONG(&const_PHP_value, PHAR_MIME_PHP);
+	zend_string *const_PHP_name = zend_string_init_interned("PHP", sizeof("PHP") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_PHP_name, &const_PHP_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_PHP_name);
+
+	zval const_PHPS_value;
+	ZVAL_LONG(&const_PHPS_value, PHAR_MIME_PHPS);
+	zend_string *const_PHPS_name = zend_string_init_interned("PHPS", sizeof("PHPS") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_PHPS_name, &const_PHPS_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_PHPS_name);
+
+	zval const_MD5_value;
+	ZVAL_LONG(&const_MD5_value, PHAR_SIG_MD5);
+	zend_string *const_MD5_name = zend_string_init_interned("MD5", sizeof("MD5") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_MD5_name, &const_MD5_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_MD5_name);
+
+	zval const_OPENSSL_value;
+	ZVAL_LONG(&const_OPENSSL_value, PHAR_SIG_OPENSSL);
+	zend_string *const_OPENSSL_name = zend_string_init_interned("OPENSSL", sizeof("OPENSSL") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_OPENSSL_name, &const_OPENSSL_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_OPENSSL_name);
+
+	zval const_OPENSSL_SHA256_value;
+	ZVAL_LONG(&const_OPENSSL_SHA256_value, PHAR_SIG_OPENSSL_SHA256);
+	zend_string *const_OPENSSL_SHA256_name = zend_string_init_interned("OPENSSL_SHA256", sizeof("OPENSSL_SHA256") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_OPENSSL_SHA256_name, &const_OPENSSL_SHA256_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_OPENSSL_SHA256_name);
+
+	zval const_OPENSSL_SHA512_value;
+	ZVAL_LONG(&const_OPENSSL_SHA512_value, PHAR_SIG_OPENSSL_SHA512);
+	zend_string *const_OPENSSL_SHA512_name = zend_string_init_interned("OPENSSL_SHA512", sizeof("OPENSSL_SHA512") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_OPENSSL_SHA512_name, &const_OPENSSL_SHA512_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_OPENSSL_SHA512_name);
+
+	zval const_SHA1_value;
+	ZVAL_LONG(&const_SHA1_value, PHAR_SIG_SHA1);
+	zend_string *const_SHA1_name = zend_string_init_interned("SHA1", sizeof("SHA1") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_SHA1_name, &const_SHA1_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_SHA1_name);
+
+	zval const_SHA256_value;
+	ZVAL_LONG(&const_SHA256_value, PHAR_SIG_SHA256);
+	zend_string *const_SHA256_name = zend_string_init_interned("SHA256", sizeof("SHA256") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_SHA256_name, &const_SHA256_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_SHA256_name);
+
+	zval const_SHA512_value;
+	ZVAL_LONG(&const_SHA512_value, PHAR_SIG_SHA512);
+	zend_string *const_SHA512_name = zend_string_init_interned("SHA512", sizeof("SHA512") - 1, 1);
+	zend_declare_typed_class_constant(class_entry, const_SHA512_name, &const_SHA512_value, ZEND_ACC_PUBLIC, NULL, (zend_type) ZEND_TYPE_INIT_MASK(MAY_BE_LONG));
+	zend_string_release(const_SHA512_name);
+
+	return class_entry;
+}
+
+static zend_class_entry *register_class_PharData(zend_class_entry *class_entry_RecursiveDirectoryIterator, zend_class_entry *class_entry_Countable, zend_class_entry *class_entry_ArrayAccess)
+{
+	zend_class_entry ce, *class_entry;
+
+	INIT_CLASS_ENTRY(ce, "PharData", class_PharData_methods);
+	class_entry = zend_register_internal_class_ex(&ce, class_entry_RecursiveDirectoryIterator);
+	zend_class_implements(class_entry, 2, class_entry_Countable, class_entry_ArrayAccess);
+
+	return class_entry;
+}
+
+static zend_class_entry *register_class_PharFileInfo(zend_class_entry *class_entry_SplFileInfo)
+{
+	zend_class_entry ce, *class_entry;
+
+	INIT_CLASS_ENTRY(ce, "PharFileInfo", class_PharFileInfo_methods);
+	class_entry = zend_register_internal_class_ex(&ce, class_entry_SplFileInfo);
+
+	return class_entry;
+}
