@@ -118,9 +118,7 @@ static const char *php_gai_strerror(int code)
 		{EAI_NONAME, "Name or service not known"},
 		{EAI_SERVICE, "Servname not supported for ai_socktype"},
 		{EAI_SOCKTYPE, "ai_socktype not supported"},
-#  ifdef EAI_SYSTEM
 		{EAI_SYSTEM, "System error"},
-#  endif
 		{0, NULL}
 	};
 	int i;
@@ -970,7 +968,7 @@ connected:
 /* }}} */
 
 /* {{{ php_any_addr
- * Fills the any (wildcard) address into php_sockaddr_storage
+ * Fills any (wildcard) address into php_sockaddr_storage
  */
 PHPAPI void php_any_addr(int family, php_sockaddr_storage *addr, unsigned short port)
 {
